@@ -1,7 +1,7 @@
-/* $Id: lc3barch.h 1591 2006-07-13 03:25:38Z peter $
+/* $Id: lc3barch.h 1914 2007-08-20 05:13:35Z peter $
  * LC-3b Architecture header file
  *
- *  Copyright (C) 2003  Peter Johnson
+ *  Copyright (C) 2003-2007  Peter Johnson
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -29,48 +29,42 @@
 
 /* Types of immediate.  All immediates are stored in the LSBs of the insn. */
 typedef enum lc3b_imm_type {
-    LC3B_IMM_NONE = 0,	/* no immediate */
-    LC3B_IMM_4,		/* 4-bit */
-    LC3B_IMM_5,		/* 5-bit */
-    LC3B_IMM_6_WORD,	/* 6-bit, word-multiple (byte>>1) */
-    LC3B_IMM_6_BYTE,	/* 6-bit, byte-multiple */
-    LC3B_IMM_8,		/* 8-bit, word-multiple (byte>>1) */
-    LC3B_IMM_9,		/* 9-bit, signed, word-multiple (byte>>1) */
-    LC3B_IMM_9_PC	/* 9-bit, signed, word-multiple, PC relative */
+    LC3B_IMM_NONE = 0,  /* no immediate */
+    LC3B_IMM_4,         /* 4-bit */
+    LC3B_IMM_5,         /* 5-bit */
+    LC3B_IMM_6_WORD,    /* 6-bit, word-multiple (byte>>1) */
+    LC3B_IMM_6_BYTE,    /* 6-bit, byte-multiple */
+    LC3B_IMM_8,         /* 8-bit, word-multiple (byte>>1) */
+    LC3B_IMM_9,         /* 9-bit, signed, word-multiple (byte>>1) */
+    LC3B_IMM_9_PC       /* 9-bit, signed, word-multiple, PC relative */
 } lc3b_imm_type;
 
 /* Bytecode types */
 
 typedef struct lc3b_insn {
-    yasm_value imm;		/* immediate or relative value */
-    lc3b_imm_type imm_type;	/* size of the immediate */
+    yasm_value imm;             /* immediate or relative value */
+    lc3b_imm_type imm_type;     /* size of the immediate */
 
-    /* PC origin if needed */
-    /*@null@*/ /*@dependent@*/ yasm_bytecode *origin_prevbc;
-
-    unsigned int opcode;	/* opcode */
+    unsigned int opcode;        /* opcode */
 } lc3b_insn;
 
 void yasm_lc3b__bc_transform_insn(yasm_bytecode *bc, lc3b_insn *insn);
 
-void yasm_lc3b__parse_cpu(yasm_arch *arch, const char *cpuid, size_t cpuid_len,
-			  unsigned long line);
-
 yasm_arch_insnprefix yasm_lc3b__parse_check_insnprefix
-    (yasm_arch *arch, unsigned long data[4], const char *id, size_t id_len,
-     unsigned long line);
+    (yasm_arch *arch, const char *id, size_t id_len, unsigned long line,
+     /*@out@*/ /*@only@*/ yasm_bytecode **bc, /*@out@*/ uintptr_t *prefix);
 yasm_arch_regtmod yasm_lc3b__parse_check_regtmod
-    (yasm_arch *arch, unsigned long *data, const char *id, size_t id_len,
-     unsigned long line);
-
-void yasm_lc3b__finalize_insn
-    (yasm_arch *arch, yasm_bytecode *bc, yasm_bytecode *prev_bc,
-     const unsigned long data[4], int num_operands,
-     /*@null@*/ yasm_insn_operands *operands, int num_prefixes,
-     unsigned long **prefixes, int num_segregs, const unsigned long *segregs);
+    (yasm_arch *arch, const char *id, size_t id_len,
+     /*@out@*/ uintptr_t *data);
 
 int yasm_lc3b__intnum_tobytes
     (yasm_arch *arch, const yasm_intnum *intn, unsigned char *buf,
      size_t destsize, size_t valsize, int shift, const yasm_bytecode *bc,
-     int warn, unsigned long line);
+     int warn);
+
+/*@only@*/ yasm_bytecode *yasm_lc3b__create_empty_insn(yasm_arch *arch,
+                                                       unsigned long line);
+
+void yasm_lc3b__ea_destroy(/*@only@*/ yasm_effaddr *ea);
+
 #endif
