@@ -1,4 +1,4 @@
-/* $Id: x86arch.h 2279 2010-01-19 07:57:43Z peter $
+/* $Id: x86arch.h 2346 2010-08-01 01:37:37Z peter $
  * x86 Architecture header file
  *
  *  Copyright (C) 2001-2007  Peter Johnson
@@ -72,7 +72,12 @@
 #define CPU_MOVBE   38      /* MOVBE instruction */
 #define CPU_XOP     39      /* AMD XOP extensions */
 #define CPU_FMA4    40      /* AMD Fused-Multiply-Add extensions */
-#define CPU_CVT16   41      /* AMD CVT16 extensions */
+#define CPU_F16C    41      /* Intel float-16 instructions */
+#define CPU_FSGSBASE 42     /* Intel FSGSBASE instructions */
+#define CPU_RDRAND  43      /* Intel RDRAND instruction */
+#define CPU_XSAVEOPT 44     /* Intel XSAVEOPT instruction */
+#define CPU_EPTVPID 45      /* Intel INVEPT, INVVPID instructions */
+#define CPU_SMX     46      /* Intel SMX instruction (GETSEC) */
 
 enum x86_parser_type {
     X86_PARSER_NASM = 0,
