@@ -25,7 +25,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include <util.h>
-/*@unused@*/ RCSID("$Id: dwarf2-aranges.c 1974 2007-09-21 16:37:01Z peter $");
+/*@unused@*/ RCSID("$Id: dwarf2-aranges.c 2010 2007-11-14 08:33:32Z peter $");
 
 #include <libyasm.h>
 
@@ -89,7 +89,7 @@ yasm_dwarf2__generate_aranges(yasm_object *object, yasm_section *debug_info)
     dwarf2_aranges_info info;
 
     debug_aranges =
-        yasm_object_get_general(object, ".debug_aranges", 0,
+        yasm_object_get_general(object, ".debug_aranges",
                                 2*dbgfmt_dwarf2->sizeof_address, 0, 0, &new,
                                 0);
 
